/* gnome-klotski.c generated by valac 0.38.0.11-8bd7f, the Vala compiler
 * generated from gnome-klotski.vala, do not modify */

/*
 * Copyright (C) 2010-2013 Robert Ancell
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version. See http://www.gnu.org/copyleft/gpl.html the full text of the
 * license.
 */

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <stdlib.h>
#include <string.h>
#include <locale.h>
#include <stdio.h>


#define TYPE_KLOTSKI (klotski_get_type ())
#define KLOTSKI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_KLOTSKI, Klotski))
#define KLOTSKI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_KLOTSKI, KlotskiClass))
#define IS_KLOTSKI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_KLOTSKI))
#define IS_KLOTSKI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_KLOTSKI))
#define KLOTSKI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_KLOTSKI, KlotskiClass))

typedef struct _Klotski Klotski;
typedef struct _KlotskiClass KlotskiClass;
typedef struct _KlotskiPrivate KlotskiPrivate;
enum  {
	KLOTSKI_DUMMY_PROPERTY,
	KLOTSKI_LAST_PROPERTY
};
static GParamSpec* klotski_properties[KLOTSKI_LAST_PROPERTY];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_KLOTSKI_WINDOW (klotski_window_get_type ())
#define KLOTSKI_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_KLOTSKI_WINDOW, KlotskiWindow))
#define KLOTSKI_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_KLOTSKI_WINDOW, KlotskiWindowClass))
#define IS_KLOTSKI_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_KLOTSKI_WINDOW))
#define IS_KLOTSKI_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_KLOTSKI_WINDOW))
#define KLOTSKI_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_KLOTSKI_WINDOW, KlotskiWindowClass))

typedef struct _KlotskiWindow KlotskiWindow;
typedef struct _KlotskiWindowClass KlotskiWindowClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

struct _Klotski {
	GtkApplication parent_instance;
	KlotskiPrivate * priv;
};

struct _KlotskiClass {
	GtkApplicationClass parent_class;
};


static gpointer klotski_parent_class = NULL;

GType klotski_get_type (void) G_GNUC_CONST;
static void klotski_scores_cb (Klotski* self);
static void _klotski_scores_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void klotski_help_cb (Klotski* self);
static void _klotski_help_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void klotski_about_cb (Klotski* self);
static void _klotski_about_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void klotski_quit_cb (Klotski* self);
static void _klotski_quit_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
gint klotski_main (gchar** args, int args_length1);
Klotski* klotski_new (void);
Klotski* klotski_construct (GType object_type);
static gint klotski_real_handle_local_options (GApplication* base, GVariantDict* options);
static void klotski_real_startup (GApplication* base);
KlotskiWindow* klotski_window_new (void);
KlotskiWindow* klotski_window_construct (GType object_type);
GType klotski_window_get_type (void) G_GNUC_CONST;
static void klotski_real_activate (GApplication* base);
void klotski_window_show_scores (KlotskiWindow* self);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

static const GOptionEntry KLOTSKI_option_entries[2] = {{"version", 'v', 0, G_OPTION_ARG_NONE, NULL, N_ ("Print release version and exit"), NULL}, {NULL}};
static const GActionEntry KLOTSKI_action_entries[4] = {{"scores", _klotski_scores_cb_gsimple_action_activate_callback}, {"help", _klotski_help_cb_gsimple_action_activate_callback}, {"about", _klotski_about_cb_gsimple_action_activate_callback}, {"quit", _klotski_quit_cb_gsimple_action_activate_callback}};

static void _klotski_scores_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	klotski_scores_cb ((Klotski*) self);
#line 94 "gnome-klotski.c"
}


static void _klotski_help_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	klotski_help_cb ((Klotski*) self);
#line 101 "gnome-klotski.c"
}


static void _klotski_about_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	klotski_about_cb ((Klotski*) self);
#line 108 "gnome-klotski.c"
}


static void _klotski_quit_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	klotski_quit_cb ((Klotski*) self);
#line 115 "gnome-klotski.c"
}


gint klotski_main (gchar** args, int args_length1) {
	gint result = 0;
	Klotski* app = NULL;
	Klotski* _tmp0_;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gint _tmp2_;
#line 35 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	setlocale (LC_ALL, "");
#line 36 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
#line 37 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
#line 38 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	textdomain (GETTEXT_PACKAGE);
#line 40 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp0_ = klotski_new ();
#line 40 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	app = _tmp0_;
#line 41 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp1_ = args;
#line 41 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp1__length1 = args_length1;
#line 41 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp2_ = g_application_run ((GApplication*) app, _tmp1__length1, _tmp1_);
#line 41 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	result = _tmp2_;
#line 41 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_g_object_unref0 (app);
#line 41 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	return result;
#line 150 "gnome-klotski.c"
}


int main (int argc, char ** argv) {
#line 33 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	return klotski_main (argv, argc);
#line 157 "gnome-klotski.c"
}


Klotski* klotski_construct (GType object_type) {
	Klotski * self = NULL;
#line 46 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	self = (Klotski*) g_object_new (object_type, "application-id", "org.gnome.klotski", "flags", G_APPLICATION_FLAGS_NONE, NULL);
#line 48 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	g_application_add_main_option_entries ((GApplication*) self, KLOTSKI_option_entries);
#line 44 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	return self;
#line 169 "gnome-klotski.c"
}


Klotski* klotski_new (void) {
#line 44 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	return klotski_construct (TYPE_KLOTSKI);
#line 176 "gnome-klotski.c"
}


static gint klotski_real_handle_local_options (GApplication* base, GVariantDict* options) {
	Klotski * self;
	gint result = 0;
	GVariantDict* _tmp0_;
	gboolean _tmp1_;
#line 51 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	self = (Klotski*) base;
#line 51 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	g_return_val_if_fail (options != NULL, 0);
#line 53 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp0_ = options;
#line 53 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp1_ = g_variant_dict_contains (_tmp0_, "version");
#line 53 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	if (_tmp1_) {
#line 195 "gnome-klotski.c"
		FILE* _tmp2_;
#line 56 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		_tmp2_ = stdout;
#line 56 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		fprintf (_tmp2_, "%1$s %2$s\n", "gnome-klotski", VERSION);
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		result = EXIT_SUCCESS;
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		return result;
#line 205 "gnome-klotski.c"
	}
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	result = -1;
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	return result;
#line 211 "gnome-klotski.c"
}


static void klotski_real_startup (GApplication* base) {
	Klotski * self;
	KlotskiWindow* _tmp0_;
	KlotskiWindow* _tmp1_;
	gchar* _tmp2_;
	gchar** _tmp3_;
	gchar** _tmp4_;
	gint _tmp4__length1;
	gchar* _tmp5_;
	gchar** _tmp6_;
	gchar** _tmp7_;
	gint _tmp7__length1;
	gchar* _tmp8_;
	gchar** _tmp9_;
	gchar** _tmp10_;
	gint _tmp10__length1;
	gchar* _tmp11_;
	gchar** _tmp12_;
	gchar** _tmp13_;
	gint _tmp13__length1;
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	self = (Klotski*) base;
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	G_APPLICATION_CLASS (klotski_parent_class)->startup ((GApplication*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_get_type (), GtkApplication));
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	g_set_application_name (_ ("Klotski"));
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	gtk_window_set_default_icon_name ("gnome-klotski");
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	g_action_map_add_action_entries ((GActionMap*) self, KLOTSKI_action_entries, G_N_ELEMENTS (KLOTSKI_action_entries), self);
#line 71 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp0_ = klotski_window_new ();
#line 71 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	g_object_ref_sink (_tmp0_);
#line 71 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp1_ = _tmp0_;
#line 71 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	gtk_application_add_window ((GtkApplication*) self, (GtkWindow*) _tmp1_);
#line 71 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_g_object_unref0 (_tmp1_);
#line 74 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp2_ = g_strdup ("Up");
#line 74 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp3_ = g_new0 (gchar*, 1 + 1);
#line 74 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp3_[0] = _tmp2_;
#line 74 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp4_ = _tmp3_;
#line 74 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp4__length1 = 1;
#line 74 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	gtk_application_set_accels_for_action ((GtkApplication*) self, "win.prev-puzzle", _tmp4_);
#line 74 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp4_ = (_vala_array_free (_tmp4_, _tmp4__length1, (GDestroyNotify) g_free), NULL);
#line 75 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp5_ = g_strdup ("Down");
#line 75 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp6_ = g_new0 (gchar*, 1 + 1);
#line 75 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp6_[0] = _tmp5_;
#line 75 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp7_ = _tmp6_;
#line 75 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp7__length1 = 1;
#line 75 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	gtk_application_set_accels_for_action ((GtkApplication*) self, "win.next-puzzle", _tmp7_);
#line 75 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp7_ = (_vala_array_free (_tmp7_, _tmp7__length1, (GDestroyNotify) g_free), NULL);
#line 76 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp8_ = g_strdup ("Page_Up");
#line 76 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp9_ = g_new0 (gchar*, 1 + 1);
#line 76 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp9_[0] = _tmp8_;
#line 76 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp10_ = _tmp9_;
#line 76 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp10__length1 = 1;
#line 76 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	gtk_application_set_accels_for_action ((GtkApplication*) self, "win.prev-pack", _tmp10_);
#line 76 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp10_ = (_vala_array_free (_tmp10_, _tmp10__length1, (GDestroyNotify) g_free), NULL);
#line 77 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp11_ = g_strdup ("Page_Down");
#line 77 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp12_ = g_new0 (gchar*, 1 + 1);
#line 77 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp12_[0] = _tmp11_;
#line 77 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp13_ = _tmp12_;
#line 77 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp13__length1 = 1;
#line 77 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	gtk_application_set_accels_for_action ((GtkApplication*) self, "win.next-pack", _tmp13_);
#line 77 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp13_ = (_vala_array_free (_tmp13_, _tmp13__length1, (GDestroyNotify) g_free), NULL);
#line 311 "gnome-klotski.c"
}


static void klotski_real_activate (GApplication* base) {
	Klotski * self;
	GtkWindow* _tmp0_;
#line 80 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	self = (Klotski*) base;
#line 82 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp0_ = gtk_application_get_active_window ((GtkApplication*) self);
#line 82 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	gtk_window_present (_tmp0_);
#line 324 "gnome-klotski.c"
}


static void klotski_scores_cb (Klotski* self) {
	GtkWindow* _tmp0_;
#line 89 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	g_return_if_fail (self != NULL);
#line 91 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp0_ = gtk_application_get_active_window ((GtkApplication*) self);
#line 91 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	klotski_window_show_scores (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_KLOTSKI_WINDOW, KlotskiWindow));
#line 336 "gnome-klotski.c"
}


static void klotski_help_cb (Klotski* self) {
	GError * _inner_error_ = NULL;
#line 94 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	g_return_if_fail (self != NULL);
#line 344 "gnome-klotski.c"
	{
		GtkWindow* _tmp0_;
		GdkScreen* _tmp1_;
		guint32 _tmp2_;
#line 98 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		_tmp0_ = gtk_application_get_active_window ((GtkApplication*) self);
#line 98 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		_tmp1_ = gtk_window_get_screen (_tmp0_);
#line 98 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		_tmp2_ = gtk_get_current_event_time ();
#line 98 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		gtk_show_uri (_tmp1_, "help:gnome-klotski", _tmp2_, &_inner_error_);
#line 98 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 359 "gnome-klotski.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		e = _inner_error_;
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		_inner_error_ = NULL;
#line 102 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		_tmp3_ = e;
#line 102 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		_tmp4_ = _tmp3_->message;
#line 102 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		g_warning ("gnome-klotski.vala:102: Failed to show help: %s", _tmp4_);
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		_g_error_free0 (e);
#line 381 "gnome-klotski.c"
	}
	__finally0:
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		g_clear_error (&_inner_error_);
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
		return;
#line 392 "gnome-klotski.c"
	}
}


static void klotski_about_cb (Klotski* self) {
#line 108 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	static const gchar* authors[] = {"Lars Rydlinge (original author)", "Robert Ancell (port to vala)", "John Cheetham (port to vala)", NULL};
#line 109 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	static const gchar* documenters[] = {"Andrew Sobala", NULL};
#line 402 "gnome-klotski.c"
	GtkWindow* _tmp0_;
#line 106 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	g_return_if_fail (self != NULL);
#line 111 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp0_ = gtk_application_get_active_window ((GtkApplication*) self);
#line 111 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	gtk_show_about_dialog (_tmp0_, "program-name", _ ("Klotski"), "version", VERSION, "comments", _ ("Sliding block puzzles"), "copyright", "Copyright © 1999–2008 Lars Rydlinge\n" "Copyright © 2014–2016 Michael Catanzaro\n" "Copyright © 2015 Arnaud Bonatti\n", "license-type", GTK_LICENSE_GPL_3_0, "authors", authors, "documenters", documenters, "translator-credits", _ ("translator-credits"), "logo-icon-name", "gnome-klotski", "website", "https://wiki.gnome.org/Apps/Klotski", NULL, NULL);
#line 410 "gnome-klotski.c"
}


static void klotski_quit_cb (Klotski* self) {
	GtkWindow* _tmp0_;
#line 128 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	g_return_if_fail (self != NULL);
#line 130 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	_tmp0_ = gtk_application_get_active_window ((GtkApplication*) self);
#line 130 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	gtk_widget_destroy ((GtkWidget*) _tmp0_);
#line 422 "gnome-klotski.c"
}


static void klotski_class_init (KlotskiClass * klass) {
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	klotski_parent_class = g_type_class_peek_parent (klass);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	((GApplicationClass *) klass)->handle_local_options = (gint (*) (GApplication *, GVariantDict*)) klotski_real_handle_local_options;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	((GApplicationClass *) klass)->startup = (void (*) (GApplication *)) klotski_real_startup;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-klotski/src/gnome-klotski.vala"
	((GApplicationClass *) klass)->activate = (void (*) (GApplication *)) klotski_real_activate;
#line 435 "gnome-klotski.c"
}


static void klotski_instance_init (Klotski * self) {
}


GType klotski_get_type (void) {
	static volatile gsize klotski_type_id__volatile = 0;
	if (g_once_init_enter (&klotski_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (KlotskiClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) klotski_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Klotski), 0, (GInstanceInitFunc) klotski_instance_init, NULL };
		GType klotski_type_id;
		klotski_type_id = g_type_register_static (gtk_application_get_type (), "Klotski", &g_define_type_info, 0);
		g_once_init_leave (&klotski_type_id__volatile, klotski_type_id);
	}
	return klotski_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



